==> prestashop_1.4.9.0.zip: prestashop/modules/vatnumber/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{vatnumber}prestashop>vatnumber_b0b9a606a1c251323825ca45d40964dc'] = 'Kein Standardland gesetzt';
$_MODULE['<{vatnumber}prestashop>vatnumber_cee549912e318726d2c4989bb507665f'] = 'Europäische MwSt.-Identifikationsnummer ';
$_MODULE['<{vatnumber}prestashop>vatnumber_a6d69adb6cb6aafd65871bde8fd51847'] = 'Aktivieren Sie die Umsatzsteuer-Identifikationsnummer bei Erstellung eines Kontos (der Kunde muss seine UST-ID bei Anlage der Adresse angeben)';
$_MODULE['<{vatnumber}prestashop>vatnumber_162b29cf61678af2aaac37f440265c28'] = 'Ihr Land wurde aktualisiert.';
$_MODULE['<{vatnumber}prestashop>vatnumber_624dd015a4cd269514f986c0a32fd076'] = 'Die Überprüfung der Umsatzsteuer-Identifikationsnummer mit dem WebService ist nun aktiviert.';
$_MODULE['<{vatnumber}prestashop>vatnumber_9e6ea8005d3440714303fc266dbdc1b4'] = 'Die Überprüfung der Umsatzsteuer-Identifikationsnummer mit dem WebService ist nun deaktiviert.';
$_MODULE['<{vatnumber}prestashop>vatnumber_56564e0a106b0e0e2dc57b5a105ed639'] = 'Ihr Land';
$_MODULE['<{vatnumber}prestashop>vatnumber_038b34b36ec9eaf5f96d11e17f208f1b'] = '- Wählen Sie ein Land -';
$_MODULE['<{vatnumber}prestashop>vatnumber_31cd0cfe3f3caacb421892056b2d80c9'] = 'Aktivieren Sie die Überprüfung der Umsatzsteuer-Identifikationsnummer mit dem WebService';
$_MODULE['<{vatnumber}prestashop>vatnumber_0a57ec92318a15681fb878bc2931480c'] = 'Die Überprüfung durch den Webservice ist langsam. Das Aktivieren dieser Option kann Ihren Shop verlangsamen.';
$_MODULE['<{vatnumber}prestashop>vatnumber_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';

==> prestashop_1.4.11.1.zip: prestashop/modules/vatnumber/de.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{vatnumber}prestashop>vatnumber_b0b9a606a1c251323825ca45d40964dc'] = 'Kein Standardland festgesetzt.';
$_MODULE['<{vatnumber}prestashop>vatnumber_cee549912e318726d2c4989bb507665f'] = 'Europäische USt-Identifikationsnummer';
$_MODULE['<{vatnumber}prestashop>vatnumber_a6d69adb6cb6aafd65871bde8fd51847'] = 'Aktivieren Sie die Umsatzsteuer-Identifikationsnummer bei Erstellung eines Kontos (der Kunde muss seine UST-ID bei Anlage der Adresse angeben)';
$_MODULE['<{vatnumber}prestashop>vatnumber_162b29cf61678af2aaac37f440265c28'] = 'Ihr Land wurde aktualisiert.';
$_MODULE['<{vatnumber}prestashop>vatnumber_624dd015a4cd269514f986c0a32fd076'] = 'Die Überprüfung der Umsatzsteuer-Identifikationsnummer mit dem WebService ist nun aktiviert.';
$_MODULE['<{vatnumber}prestashop>vatnumber_9e6ea8005d3440714303fc266dbdc1b4'] = 'Die Überprüfung der Umsatzsteuer-Identifikationsnummer mit dem WebService ist nun deaktiviert.';
$_MODULE['<{vatnumber}prestashop>vatnumber_56564e0a106b0e0e2dc57b5a105ed639'] = 'Ihr Land';
$_MODULE['<{vatnumber}prestashop>vatnumber_038b34b36ec9eaf5f96d11e17f208f1b'] = '- Wählen Sie ein Land -';
$_MODULE['<{vatnumber}prestashop>vatnumber_31cd0cfe3f3caacb421892056b2d80c9'] = 'Aktivieren Sie die Überprüfung der Umsatzsteuer-Identifikationsnummer mit dem WebService';
$_MODULE['<{vatnumber}prestashop>vatnumber_0a57ec92318a15681fb878bc2931480c'] = 'Die Überprüfung durch den Webservice ist langsam. Das Aktivieren dieser Option kann Ihren Shop verlangsamen.';
$_MODULE['<{vatnumber}prestashop>vatnumber_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';
